require_relative '../../spec_helper'

describe :rational_marshal_dump, shared: true do
  it "needs to be reviewed for spec completeness"
end
